A dataset containing the data of three replications and 48 progenies with 7 different traits.
Usage
data(seldata)pkgdown/includes/in_header.html
Skip to contentsA dataset containing the data of three replications and 48 progenies with 7 different traits.
data(seldata)