selection.index-package: selection.index: Analysis of Selection Index in Plant...

selection.index-packageR Documentation

selection.index: Analysis of Selection Index in Plant Breeding

Description

Provides tools for the simultaneous improvement of multiple traits in plant breeding. Building upon the classical selection index (Smith 1937 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/j.1469-1809.1936.tb02143.x")}) and modern quantitative genetics (Kang 2020 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/978-3-319-91223-3")}), this package calculates classical phenotypic, genomic, marker-assisted, restricted/constrained, and eigen selection indices. It also incorporates multi-stage selection evaluation and stochastic simulations to estimate genetic advance based on economic weights, heritability, and genetic correlations.

Author(s)

Maintainer: Zankrut Goyani zankrut20@gmail.com [copyright holder]

See Also

Useful links:


selection.index documentation built on March 9, 2026, 1:06 a.m.